#include <Arduino.h>

#include <LiquidCrystal.h>      // lcd knjižnica

// Set the LCD 
LiquidCrystal lcd(11, 10, 9, 7, 6, 5); // lcd pin

// variables..
int time_ms_min = 0;
int time_ms_max = 500;

int time_ms1;
int time_ms2;
int time_ms3;

// pins 
int weld_pin     = 8;
int weld_button  = 2; // with pull down resistor
int PIN_A   = 3; // with pull down resistor
int PIN_B   = 4; // with pull down resistor

void setup()
{
  // initialize the digital pin for welding as an output.
  pinMode(weld_pin, OUTPUT);

  // initialize the LCD
  lcd.begin(16, 2);                   // 16 znakov 2 vrstici

  // Turn on the blacklight and print a message.

  lcd.setCursor(0,1);
  lcd.print("Initializing...");

}

void loop()
{

  char mybuffer[16]; // working variable
 
  // Probe working mode
  bool manual_welding_flag   = (digitalRead(PIN_A) != LOW) && (digitalRead(PIN_B) == LOW);
  bool set_welding_time_flag = (digitalRead(PIN_A) == LOW) && (digitalRead(PIN_B) == LOW);
  bool contrl_welding_flag   = (digitalRead(PIN_A) == LOW) && (digitalRead(PIN_B) != LOW);

  // =====  RUN DIRECT BUTTON WELDING  ====
  if(manual_welding_flag) 
  { // Check the button until it stays on!
  
    // Write on LCD display
    lcd.clear();
    lcd.setCursor(0,0);
    lcd.print("Manual Welding");
    lcd.setCursor(0,1);
    lcd.print("Push button.");
    
    delay(200);
    
    // Is the welding button on? (check for a while)
    for(int ii = 0; ii < 100; ++ii) {
      
      if(digitalRead(weld_button) != LOW) { // Hey, welding button was triggered!

        digitalWrite(weld_pin, HIGH); // weld power ON
      
        while(digitalRead(weld_button) != LOW) { // Loop until welding button is on
          delay(0.1); // 1ms delay..
          
          lcd.setCursor(0,1);
          lcd.print("Push button. *");
        }

      digitalWrite(weld_pin, LOW); // weld power OFF

      }      
    } 
  }

  // =====  SET WELDING TIMES  =====
  if(set_welding_time_flag) { // Run the "times setting sub-program":
  //     0) write header line on LCD
  //     1) read potentiometers
  //     2) set cursor to begin of second line
  //     3) write values in milliseconds

    // Write header line
    lcd.clear();
    lcd.setCursor(0,0); // first line
    lcd.print("Pre  Pause  Weld");
    lcd.setCursor(0,1); // new line
    
    // Now read dynamically the trimmers, for a while
    for (int ii = 0; ii < 3; ++ii) {
      // Read trimmers and set the pre-welding, pause and weld times according
      int   trimmer1 = analogRead(A2); 
      int   trimmer2 = analogRead(A1); 
      int   trimmer3 = analogRead(A0); 
      float value1   = trimmer1/1023.0; // get a value for trigger1, going from 0 to 1
      float value2   = trimmer2/1023.0; // get a value for trigger1, going from 0 to 1
      float value3   = trimmer3/1023.0; // get a value for trigger1, going from 0 to 1

      time_ms1 = time_ms_min + value1 *(time_ms_max - time_ms_min);
      time_ms2 = time_ms_min + value2 *(time_ms_max - time_ms_min);
      time_ms3 = time_ms_min + value3 *(time_ms_max - time_ms_min);    
  
      delay(100); // pause for a bit..

      lcd.setCursor(0,1); // move back cursor to zero, to re-write the line
      sprintf(mybuffer,"%03d   %03d   %03d", time_ms1, time_ms2, time_ms3);
      lcd.print(mybuffer);
    }
  }
  
  // ===== RUN TIME-CONTROLLED WELDING =====
  if(contrl_welding_flag) {
    lcd.clear();
    lcd.setCursor(0,0);
    lcd.print("Contrl. Welding");
    lcd.setCursor(0,1);
    lcd.print("Push button.");
    
    delay(200);
    
    // Now check for a while if I press the button
    for(int ii =0; ii < 100; ++ii) {

      // Check welding button
      if(digitalRead(weld_button) != LOW) { // pressed!
      
        lcd.setCursor(0,1);
        lcd.print("Push button. *");
        
        // pre-weld
        digitalWrite(weld_pin, HIGH); // weld power ON
        delay(time_ms1);

        // pause
        digitalWrite(weld_pin, LOW);  // weld power OFF
        delay(time_ms2); 

        // weld        
        digitalWrite(weld_pin, HIGH); // weld power ON
        delay(time_ms3);

        // and finally switch off
        digitalWrite(weld_pin, LOW);  // weld power OFF

        lcd.setCursor(0,1);
        lcd.print("Push button.   ");
        
        delay(1000); // wait for 1 second before continuing (anti bounce for button)
      }
      
    }
  }

}


